@@ -2,12 +2,14 @@
 """remove a vospace data node, fails if container node or node is locked."""
 import logging
 from ..commonparser import set_logging_level_from_args, exit_on_exception, \
-    CommonParser
+    CommonParser, URI_DESCRIPTION
 from .. import vos
 
 DESCRIPTION = """remove a vospace data node; fails if container node or node is locked.
 
-eg. vrm vos:/root/node   -- deletes a data node"""
+{}
+
+eg. vrm vos:/root/node   -- deletes a data node""".format(URI_DESCRIPTION)
 
 
 def vrm():
@@ -20,12 +22,13 @@ def vrm():
     set_logging_level_from_args(args)
 
     try:
-        client = vos.Client(vospace_certfile=args.certfile,
-                            vospace_token=args.token)
         for node in args.node:
-            if not node.startswith('vos:'):
+            if not vos.is_remote_file(node):
                 raise Exception(
                     '{} is not a valid VOSpace handle'.format(node))
+            client = vos.Client(
+                    vospace_certfile=args.certfile,
+                    vospace_token=args.token)
             if not node.endswith('/'):
                 if client.get_node(node).islink():
                     logging.info('deleting link {}'.format(node))
