@@ -1,14 +1,16 @@
 """Delete a VOSpace ContainerNode (aka directory)"""
 from ..commonparser import CommonParser, set_logging_level_from_args, \
-    exit_on_exception
+    exit_on_exception, URI_DESCRIPTION
 import logging
 from vos import vos
 
 DESCRIPTION = """deletes a VOSpace container node (aka directory)
 
+{}
+
 e.g.   vrmdir vos:Root/MyContainer
 
-CAUTION:  The container need not be empty."""
+CAUTION:  The container need not be empty.""".format(URI_DESCRIPTION)
 
 
 def vrmdir():
@@ -21,12 +23,13 @@ def vrmdir():
     set_logging_level_from_args(args)
 
     try:
-        client = vos.Client(vospace_certfile=args.certfile,
-                            vospace_token=args.token)
         for container_node in args.nodes:
-            if not container_node.startswith("vos:"):
+            if not vos.is_remote_file(container_node):
                 raise ValueError(
                     "{} is not a valid VOSpace handle".format(container_node))
+            client = vos.Client(
+                    vospace_certfile=args.certfile,
+                    vospace_token=args.token)
             if client.isdir(container_node):
                 logging.info("deleting {}".format(container_node))
                 client.delete(container_node)
